<?php

namespace Drupal\convert_bundles\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\TempStore\PrivateTempStoreFactory;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Controller to convert entity bundles.
 *
 * @see \Drupal\convert_bundles\Routing\RouteSubscriber
 * @see \Drupal\convert_bundles\Plugin\Derivative\ConvertBundlesLocalTask
 */
class EntityController extends ControllerBase {

  /**
   * The private tempstore factory.
   *
   * @var \Drupal\Core\TempStore\PrivateTempStoreFactory
   */
  protected $tempStoreFactory;

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The current request.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $currentRequest;

  /**
   * Constructs a \Drupal\convert_bundles\Controller\EntityController.
   *
   * @param \Drupal\Core\TempStore\PrivateTempStoreFactory $temp_store_factory
   *   The private tempstore factory.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   The current user.
   * @param \Symfony\Component\HttpFoundation\Request $current_request
   *   The current request.
   */
  public function __construct(
    PrivateTempStoreFactory $temp_store_factory,
    AccountProxyInterface $current_user,
    Request $current_request,
  ) {
    $this->tempStoreFactory = $temp_store_factory;
    $this->currentUser = $current_user->id();
    $this->currentRequest = $current_request;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('tempstore.private'),
      $container->get('current_user'),
      $container->get('request_stack')->getCurrentRequest()
    );
  }

  /**
   * Retrieves entity from route match.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The entity object as determined from the passed-in route match.
   */
  public function getEntity(Request $request, RouteMatchInterface $route_match) {
    $parameter_name = $route_match->getRouteObject()->getOption('_convert_bundles_entity_type_id');
    $entity = $route_match->getParameter($parameter_name);
    $ids[$entity->id()] = $entity;
    $this->tempStoreFactory->get('convert_bundles_ids')
      ->set($this->currentUser, $ids);
    $basepath = $this->currentRequest->getBasePath() ?? '';

    return $this->redirect('convert_bundles.form', [], [
      'query' => [
        'destination' => $basepath . '/' . $entity->getEntityTypeId() . '/' . $entity->id(),
      ],
    ]);
  }

}
